@@ -1,13 +1,13 @@
 use strict; use warnings;
 package Vroom;
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 use Vroom::Mo;
 
 use File::HomeDir;
 use IO::All;
 use Template::Toolkit::Simple;
 use Term::Size;
-use YAML::XS;
+use YAML::PP;
 
 use Getopt::Long;
 use Cwd;
@@ -45,6 +45,8 @@ has config => {
     auto_size => 0,
 };
 
+my $ypp = YAML::PP->new;
+
 sub usage {
     return <<'...';
     Usage: vroom <command> [options]
@@ -185,7 +187,7 @@ sub runSlide {
         exec "clear; runghc run.slide";
     }
     elsif ($slide =~ /\.yaml$/) {
-        exec "clear; $^X -MYAML::XS -MData::Dumper -e '\$Data::Dumper::Terse = 1; \$Data::Dumper::Indent = 1; print Dumper YAML::XS::LoadFile(shift)' run.slide";
+        exec "clear; $^X -MYAML::PP -MData::Dumper -e '\$Data::Dumper::Terse = 1; \$Data::Dumper::Indent = 1; print Dumper YAML::PP::LoadFile(shift)' run.slide";
     }
     elsif ($slide =~ /\.sh$/) {
         exec "clear; $ENV{SHELL} -i run.slide";
@@ -657,7 +659,7 @@ sub applyOptions {
     if ($config->{config}) {
         $config = {
             %{$self->config},
-            %{(YAML::XS::Load($slide))},
+            %{($ypp->load_string(decode_utf8 $slide))},
         };
 
         if ($config->{auto_size}) {
